==> mattermost-models-0.1.0-sources.jar: net/bis5/mattermost/model/config/SamlSettings.java <==
/*
 * Copyright (c) 2016-present, Takayuki Maruyama
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * 	Unless required by applicable law or agreed to in writing, software
 * 	distributed under the License is distributed on an "AS IS" BASIS,
 * 	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * 	See the License for the specific language governing permissions and
 * 	limitations under the License.
 */
package net.bis5.mattermost.model.config;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import lombok.Data;

/**
 * SAML settings
 * 
 * @author Takayuki Maruyama
 */
@Data
@JsonIgnoreProperties(ignoreUnknown = true)
public class SamlSettings {

	// Basic
	private boolean enable;
	private boolean verify;
	private boolean encrypt;

	private String idpUrl;
	private String idpDescriptorUrl;
	private String assertionConsumerServiceUrl;

	private String idpCertificateFile;
	private String publicCertificateFile;
	private String privateKeyFile;

	// User Mapping
	private String firstNameAttribute;
	private String lastNameAttribute;
	private String emailAttribute;
	private String usernameAttribute;
	private String nicknameAttribute;
	private String localeAttribute;
	private String positionAttribute;

	private String loginButtonText;

	/** @since Mattermost Server 4.4 (Enterprise Edition) */
	private boolean enableSync;
	/** @since Mattermost Server 4.6 (Enterprise Edition) */
	private String loginButtonColor;
	/** @since Mattermost Server 4.6 (Enterprise Edition) */
	private String loginButtonBorderColor;
	/** @since Mattermost Server 4.6 (Enterprise Edition) */
	private String loginButtonTextColor;
	/** @since Mattermost Server 4.9 */
	private String scopingIDPProviderId;
	/** @since Mattermost Server 4.9 */
	private String scopingIDPName;

}

==> mattermost-models-0.1.1-sources.jar: net/bis5/mattermost/model/config/SamlSettings.java <==
/*
 * Copyright (c) 2016-present, Takayuki Maruyama
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *  
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * 	Unless required by applicable law or agreed to in writing, software
 * 	distributed under the License is distributed on an "AS IS" BASIS,
 * 	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * 	See the License for the specific language governing permissions and
 * 	limitations under the License.
 */
package net.bis5.mattermost.model.config;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;

import lombok.Data;
import lombok.Getter;
import lombok.Setter;

/**
 * SAML settings
 * 
 * @author Takayuki Maruyama
 */
@Data
@JsonIgnoreProperties(ignoreUnknown = true)
public class SamlSettings {

	// Basic
	private boolean enable;
	private boolean verify;
	private boolean encrypt;

	private String idpUrl;
	private String idpDescriptorUrl;
	private String assertionConsumerServiceUrl;

	private String idpCertificateFile;
	private String publicCertificateFile;
	private String privateKeyFile;

	// User Mapping
	private String firstNameAttribute;
	private String lastNameAttribute;
	private String emailAttribute;
	private String usernameAttribute;
	private String nicknameAttribute;
	private String localeAttribute;
	private String positionAttribute;

	private String loginButtonText;

	/** @since Mattermost Server 4.4 (Enterprise Edition) */
	private boolean enableSyncWithLdap;
	/** @since Mattermost Server 4.6 (Enterprise Edition) */
	private String loginButtonColor;
	/** @since Mattermost Server 4.6 (Enterprise Edition) */
	private String loginButtonBorderColor;
	/** @since Mattermost Server 4.6 (Enterprise Edition) */
	private String loginButtonTextColor;
	/** @since Mattermost Server 4.9 */
	private String scopingIDPProviderId;
	/** @since Mattermost Server 4.9 */
	private String scopingIDPName;

	@Getter(onMethod = @__({ @Deprecated }))
	@Setter(onMethod = @__({ @Deprecated }))
	private boolean enableSync;
}
